You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ha...@apache.org on 2009/03/06 09:20:11 UTC

svn commit: r750806 [5/7] - in /camel/trunk: camel-core/src/main/java/org/apache/camel/ camel-core/src/main/java/org/apache/camel/builder/ camel-core/src/main/java/org/apache/camel/impl/ camel-core/src/main/java/org/apache/camel/management/ camel-core/...

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/RoutingSlip.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/RoutingSlip.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/RoutingSlip.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/RoutingSlip.java Fri Mar  6 08:20:00 2009
@@ -23,7 +23,7 @@
 import org.apache.camel.Producer;
 import org.apache.camel.impl.ProducerCache;
 import org.apache.camel.impl.ServiceSupport;
-import org.apache.camel.model.RoutingSlipType;
+import org.apache.camel.model.RoutingSlipDefinition;
 import org.apache.camel.util.ExchangeHelper;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -42,7 +42,7 @@
     private ProducerCache producerCache = new ProducerCache();
 
     public RoutingSlip(String header) {
-        this(header, RoutingSlipType.DEFAULT_DELIMITER);
+        this(header, RoutingSlipDefinition.DEFAULT_DELIMITER);
     }
 
     public RoutingSlip(String header, String uriDelimiter) {

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/DefaultExceptionPolicyStrategy.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/DefaultExceptionPolicyStrategy.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyKey.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyKey.java Fri Mar  6 08:20:00 2009
@@ -16,7 +16,7 @@
  */
 package org.apache.camel.processor.exceptionpolicy;
 
-import org.apache.camel.model.WhenType;
+import org.apache.camel.model.WhenDefinition;
 
 /**
  * Exception policy key is a compound key for storing:
@@ -27,9 +27,9 @@
 public final class ExceptionPolicyKey {
 
     private final Class exceptionClass;
-    private final WhenType when;
+    private final WhenDefinition when;
 
-    public ExceptionPolicyKey(Class exceptionClass, WhenType when) {
+    public ExceptionPolicyKey(Class exceptionClass, WhenDefinition when) {
         this.exceptionClass = exceptionClass;
         this.when = when;
     }
@@ -38,7 +38,7 @@
         return exceptionClass;
     }
 
-    public WhenType getWhen() {
+    public WhenDefinition getWhen() {
         return when;
     }
 
@@ -46,7 +46,7 @@
         return new ExceptionPolicyKey(exceptionClass, null);
     }
 
-    public static ExceptionPolicyKey newInstance(Class exceptionClass, WhenType when) {
+    public static ExceptionPolicyKey newInstance(Class exceptionClass, WhenDefinition when) {
         return new ExceptionPolicyKey(exceptionClass, when);
     }
 

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyStrategy.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyStrategy.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DebugInterceptor.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DebugInterceptor.java Fri Mar  6 08:20:00 2009
@@ -22,7 +22,7 @@
 import org.apache.camel.Message;
 import org.apache.camel.Predicate;
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.processor.DelegateProcessor;
 
 /**
@@ -31,7 +31,7 @@
  * @version $Revision$
  */
 public class DebugInterceptor extends DelegateProcessor {
-    private final ProcessorType node;
+    private final ProcessorDefinition node;
     private final List<Exchange> exchanges;
     private final List<ExceptionEvent> exceptions;
     private Predicate traceFilter;
@@ -39,7 +39,7 @@
     private boolean traceExceptions = true;
     private boolean enabled = true;
 
-    public DebugInterceptor(ProcessorType node, Processor target, List<Exchange> exchanges, List<ExceptionEvent> exceptions) {
+    public DebugInterceptor(ProcessorDefinition node, Processor target, List<Exchange> exchanges, List<ExceptionEvent> exceptions) {
         super(target);
         this.node = node;
         this.exchanges = exchanges;
@@ -67,7 +67,7 @@
         }
     }
 
-    public ProcessorType getNode() {
+    public ProcessorDefinition getNode() {
         return node;
     }
 

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Debugger.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Debugger.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Debugger.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Debugger.java Fri Mar  6 08:20:00 2009
@@ -24,7 +24,7 @@
 import org.apache.camel.CamelContext;
 import org.apache.camel.Exchange;
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.spi.InterceptStrategy;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -115,7 +115,7 @@
     }
 
 
-    public Processor wrapProcessorInInterceptors(ProcessorType processorType, Processor target) throws Exception {
+    public Processor wrapProcessorInInterceptors(ProcessorDefinition processorType, Processor target) throws Exception {
         String id = processorType.idOrCreate();
         if (logExchanges) {
             TraceInterceptor traceInterceptor = new TraceInterceptor(processorType, target, tracer);

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceEventMessage.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceEventMessage.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceEventMessage.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceEventMessage.java Fri Mar  6 08:20:00 2009
@@ -21,7 +21,7 @@
 
 import org.apache.camel.Exchange;
 import org.apache.camel.Message;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.spi.TraceableUnitOfWork;
 import org.apache.camel.util.MessageHelper;
 
@@ -53,7 +53,7 @@
      * @param toNode the node where this trace is intercepted
      * @param exchange the current {@link Exchange}
      */
-    public DefaultTraceEventMessage(final Date timestamp, final ProcessorType toNode, final Exchange exchange) {
+    public DefaultTraceEventMessage(final Date timestamp, final ProcessorDefinition toNode, final Exchange exchange) {
         Message in = exchange.getIn();
 
         // false because we don't want to introduce side effects
@@ -81,7 +81,7 @@
 
     // Implementation
     //---------------------------------------------------------------
-    private String extractNode(ProcessorType node) {
+    private String extractNode(ProcessorDefinition node) {
         return node.getShortName() + "(" + node.getLabel() + ")";
     }
 
@@ -92,7 +92,7 @@
     private String extractPreviousNode(Exchange exchange) {
         if (exchange.getUnitOfWork() instanceof TraceableUnitOfWork) {
             TraceableUnitOfWork tuow = (TraceableUnitOfWork) exchange.getUnitOfWork();
-            ProcessorType last = tuow.getLastInterceptedNode();
+            ProcessorDefinition last = tuow.getLastInterceptedNode();
             return last != null ? extractNode(last) : null;
         }
         return null;

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceFormatter.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceFormatter.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceFormatter.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DefaultTraceFormatter.java Fri Mar  6 08:20:00 2009
@@ -18,7 +18,7 @@
 
 import org.apache.camel.Exchange;
 import org.apache.camel.Message;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.spi.TraceableUnitOfWork;
 import org.apache.camel.spi.UnitOfWork;
 import org.apache.camel.util.MessageHelper;
@@ -43,7 +43,7 @@
     private boolean showOutBodyType;
     private boolean showException = true;
 
-    public Object format(final TraceInterceptor interceptor, final ProcessorType node, final Exchange exchange) {
+    public Object format(final TraceInterceptor interceptor, final ProcessorDefinition node, final Exchange exchange) {
         Message in = exchange.getIn();
         Message out = exchange.getOut(false);
 
@@ -210,7 +210,7 @@
         return unitOfWork.getId();
     }
 
-    protected String getNodeMessage(ProcessorType node) {
+    protected String getNodeMessage(ProcessorDefinition node) {
         String message = node.getShortName() + "(" + node.getLabel() + ")";
         if (nodeLength > 0) {
             return String.format("%1$-" + nodeLength + "." + nodeLength + "s", message);
@@ -226,7 +226,7 @@
      * <br/>or
      * <br/><tt>ID-mojo/39713-1225468755256/2-0 -> transform(body)</tt>
      */
-    protected String extractBreadCrumb(TraceInterceptor interceptor, ProcessorType currentNode, Exchange exchange) {
+    protected String extractBreadCrumb(TraceInterceptor interceptor, ProcessorDefinition currentNode, Exchange exchange) {
         String id = "";
         String result;
         
@@ -249,7 +249,7 @@
         String from = "";
         if (showNode && exchange.getUnitOfWork() instanceof TraceableUnitOfWork) {
             TraceableUnitOfWork tuow = (TraceableUnitOfWork) exchange.getUnitOfWork();
-            ProcessorType prev = tuow.getLastInterceptedNode();
+            ProcessorDefinition prev = tuow.getLastInterceptedNode();
             if (prev != null) {
                 from = getNodeMessage(prev);
             } else if (exchange.getFromEndpoint() != null) {

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DelayInterceptor.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DelayInterceptor.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DelayInterceptor.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DelayInterceptor.java Fri Mar  6 08:20:00 2009
@@ -18,7 +18,7 @@
 
 import org.apache.camel.Exchange;
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.processor.DelayProcessorSupport;
 
 /**
@@ -26,10 +26,10 @@
  */
 public class DelayInterceptor extends DelayProcessorSupport {
 
-    private final ProcessorType node;
+    private final ProcessorDefinition node;
     private Delayer delayer;
 
-    public DelayInterceptor(ProcessorType node, Processor target, Delayer delayer) {
+    public DelayInterceptor(ProcessorDefinition node, Processor target, Delayer delayer) {
         super(target);
         this.node = node;
         this.delayer = delayer;

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Delayer.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Delayer.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Delayer.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Delayer.java Fri Mar  6 08:20:00 2009
@@ -20,7 +20,7 @@
 
 import org.apache.camel.CamelContext;
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.spi.InterceptStrategy;
 
 /**
@@ -54,7 +54,7 @@
         return null;
     }
 
-    public Processor wrapProcessorInInterceptors(ProcessorType processorType, Processor target) throws Exception {
+    public Processor wrapProcessorInInterceptors(ProcessorDefinition processorType, Processor target) throws Exception {
         DelayInterceptor delayer = new DelayInterceptor(processorType, target, this);
         return delayer;
     }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCaching.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCaching.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCaching.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCaching.java Fri Mar  6 08:20:00 2009
@@ -17,7 +17,7 @@
 package org.apache.camel.processor.interceptor;
 
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.spi.InterceptStrategy;
 import org.apache.camel.spi.RouteContext;
 
@@ -34,7 +34,7 @@
     }
 
     @SuppressWarnings("unchecked")
-    public Processor wrapProcessorInInterceptors(ProcessorType processorType, Processor target) throws Exception {
+    public Processor wrapProcessorInInterceptors(ProcessorDefinition processorType, Processor target) throws Exception {
         return new StreamCachingInterceptor(target);
     }
     

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCachingInterceptor.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCachingInterceptor.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCachingInterceptor.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/StreamCachingInterceptor.java Fri Mar  6 08:20:00 2009
@@ -25,7 +25,7 @@
 import org.apache.camel.Processor;
 import org.apache.camel.StreamCache;
 import org.apache.camel.model.InterceptorRef;
-import org.apache.camel.model.InterceptorType;
+import org.apache.camel.model.InterceptorDefinition;
 import org.apache.camel.processor.DelegateProcessor;
 import org.apache.camel.util.AsyncProcessorHelper;
 import org.apache.camel.util.MessageHelper;
@@ -54,9 +54,9 @@
      *
      * @param interceptors the list of interceptors
      */
-    public static void noStreamCaching(List<InterceptorType> interceptors) {
+    public static void noStreamCaching(List<InterceptorDefinition> interceptors) {
         for (int i = 0; i < interceptors.size(); i++) {
-            InterceptorType interceptor = interceptors.get(i);
+            InterceptorDefinition interceptor = interceptors.get(i);
             if (interceptor instanceof InterceptorRef
                 && ((InterceptorRef)interceptor).getInterceptor() instanceof StreamCachingInterceptor) {
                 interceptors.remove(interceptor);

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceFormatter.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceFormatter.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceFormatter.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceFormatter.java Fri Mar  6 08:20:00 2009
@@ -17,7 +17,7 @@
 package org.apache.camel.processor.interceptor;
 
 import org.apache.camel.Exchange;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 
 /**
  * Formatter to format trace logs when tracing {@link Exchange} during routing.
@@ -32,5 +32,5 @@
      * @param exchange       the current exchange
      * @return the log message
      */
-    Object format(TraceInterceptor interceptor, ProcessorType node, Exchange exchange);
+    Object format(TraceInterceptor interceptor, ProcessorDefinition node, Exchange exchange);
 }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceInterceptor.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceInterceptor.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceInterceptor.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/TraceInterceptor.java Fri Mar  6 08:20:00 2009
@@ -25,7 +25,7 @@
 import org.apache.camel.Processor;
 import org.apache.camel.Producer;
 import org.apache.camel.model.InterceptorRef;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.processor.DelegateProcessor;
 import org.apache.camel.processor.Logger;
 import org.apache.camel.spi.ExchangeFormatter;
@@ -48,12 +48,12 @@
     private static final String TRACE_EVENT = "CamelTraceEvent";
     private Logger logger;
     private Producer traceEventProducer;
-    private final ProcessorType node;
+    private final ProcessorDefinition node;
     private final Tracer tracer;
     private TraceFormatter formatter;
     private Class jpaTraceEventMessageClass;
 
-    public TraceInterceptor(ProcessorType node, Processor target, TraceFormatter formatter, Tracer tracer) {
+    public TraceInterceptor(ProcessorDefinition node, Processor target, TraceFormatter formatter, Tracer tracer) {
         super(target);
         this.tracer = tracer;
         this.node = node;
@@ -77,7 +77,7 @@
         }
     }
 
-    public TraceInterceptor(ProcessorType node, Processor target, Tracer tracer) {
+    public TraceInterceptor(ProcessorDefinition node, Processor target, Tracer tracer) {
         this(node, target, null, tracer);
     }
 
@@ -133,7 +133,7 @@
 
     // Properties
     //-------------------------------------------------------------------------
-    public ProcessorType getNode() {
+    public ProcessorDefinition getNode() {
         return node;
     }
 
@@ -239,7 +239,7 @@
     /**
      * Returns true if the given node should be logged in the trace list
      */
-    protected boolean shouldLogNode(ProcessorType node) {
+    protected boolean shouldLogNode(ProcessorDefinition node) {
         if (node == null) {
             return false;
         }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Tracer.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Tracer.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Tracer.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/Tracer.java Fri Mar  6 08:20:00 2009
@@ -23,7 +23,7 @@
 import org.apache.camel.LoggingLevel;
 import org.apache.camel.Predicate;
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.spi.InterceptStrategy;
 
 /**
@@ -61,7 +61,7 @@
         return null;
     }
 
-    public Processor wrapProcessorInInterceptors(ProcessorType processorType, Processor target) throws Exception {
+    public Processor wrapProcessorInInterceptors(ProcessorDefinition processorType, Processor target) throws Exception {
         // Force the creation of an id, otherwise the id is not available when the trace formatter is
         // outputting trace information
         String id = processorType.idOrCreate();

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/spi/ErrorHandlerWrappingStrategy.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/ErrorHandlerWrappingStrategy.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/spi/ErrorHandlerWrappingStrategy.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/spi/ErrorHandlerWrappingStrategy.java Fri Mar  6 08:20:00 2009
@@ -17,7 +17,7 @@
 package org.apache.camel.spi;
 
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 
 /**
  * The purpose of this interface is to allow an implementation to
@@ -29,7 +29,7 @@
 
     /**
      * This method is invoked by
-     * {@link ProcessorType#wrapProcessor(RouteContext, Processor)}
+     * {@link ProcessorDefinition#wrapProcessor(RouteContext, Processor)}
      * to give the implementor an opportunity to wrap the target processor
      * in a route.
      *
@@ -38,6 +38,6 @@
      * @return processor wrapped with an interceptor or not wrapped
      * @throws Exception can be thrown
      */
-    Processor wrapProcessorInErrorHandler(ProcessorType processorType, Processor target) throws Exception;
+    Processor wrapProcessorInErrorHandler(ProcessorDefinition processorType, Processor target) throws Exception;
 
 }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/spi/InterceptStrategy.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/InterceptStrategy.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/spi/InterceptStrategy.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/spi/InterceptStrategy.java Fri Mar  6 08:20:00 2009
@@ -17,7 +17,7 @@
 package org.apache.camel.spi;
 
 import org.apache.camel.Processor;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 
  /**
   * The purpose of this interface is to allow an implementation to wrap
@@ -30,7 +30,7 @@
 
     /**
      * This method is invoked by
-     * {@link ProcessorType#wrapProcessor(RouteContext, Processor)}
+     * {@link ProcessorDefinition#wrapProcessor(RouteContext, Processor)}
      * to give the implementor an opportunity to wrap the target processor
      * in a route.
      *
@@ -39,6 +39,6 @@
      * @return processor wrapped with an interceptor or not wrapped
      * @throws Exception can be thrown
      */
-    Processor wrapProcessorInInterceptors(ProcessorType processorType,
+    Processor wrapProcessorInInterceptors(ProcessorDefinition processorType,
             Processor target) throws Exception;
 }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/spi/RouteContext.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/RouteContext.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/spi/RouteContext.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/spi/RouteContext.java Fri Mar  6 08:20:00 2009
@@ -23,10 +23,10 @@
 import org.apache.camel.Exchange;
 import org.apache.camel.Intercept;
 import org.apache.camel.Processor;
-import org.apache.camel.model.FromType;
-import org.apache.camel.model.ProcessorType;
-import org.apache.camel.model.RouteType;
-import org.apache.camel.model.dataformat.DataFormatType;
+import org.apache.camel.model.FromDefinition;
+import org.apache.camel.model.ProcessorDefinition;
+import org.apache.camel.model.RouteDefinition;
+import org.apache.camel.model.dataformat.DataFormatDefinition;
 
 /**
  * The context used to activate new routing rules
@@ -47,14 +47,14 @@
      *
      * @return the from type
      */
-    FromType getFrom();
+    FromDefinition getFrom();
 
     /**
      * Get the route type
      *
      * @return the route type
      */
-    RouteType getRoute();
+    RouteDefinition getRoute();
 
     /**
      * Gets the camel context
@@ -70,7 +70,7 @@
      * @return the created processor
      * @throws Exception can be thrown
      */
-    Processor createProcessor(ProcessorType node) throws Exception;
+    Processor createProcessor(ProcessorDefinition node) throws Exception;
 
     /**
      * Resolves an endpoint from the URI
@@ -161,7 +161,7 @@
     void setErrorHandlerWrappingStrategy(ErrorHandlerWrappingStrategy strategy);
 
     /**
-     * If this flag is true, {@link ProcessorType#addRoutes(RouteContext, java.util.Collection)}
+     * If this flag is true, {@link ProcessorDefinition#addRoutes(RouteContext, java.util.Collection)}
      * will not add processor to addEventDrivenProcessor to the RouteContext and it
      * will prevent from adding an EventDrivenRoute.
      *
@@ -182,5 +182,5 @@
      * @param ref  the ref name to lookup
      * @return the found object
      */
-    DataFormatType getDataFormat(String ref);
+    DataFormatDefinition getDataFormat(String ref);
 }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TraceableUnitOfWork.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TraceableUnitOfWork.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TraceableUnitOfWork.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/spi/TraceableUnitOfWork.java Fri Mar  6 08:20:00 2009
@@ -18,7 +18,7 @@
 
 import java.util.List;
 
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 
 /**
  * A Unit of work that is also traceable with the
@@ -34,17 +34,17 @@
      *
      * @param node the node
      */
-    void addInterceptedNode(ProcessorType node);
+    void addInterceptedNode(ProcessorDefinition node);
 
     /**
      * Gets the last intercepted node, is <tt>null</tt> if no last exists.
      */
-    ProcessorType getLastInterceptedNode();
+    ProcessorDefinition getLastInterceptedNode();
 
     /**
      * Gets the current list of intercepted nodes, representing the route path the
      * current {@link org.apache.camel.Exchange} has taken.
      */
-    List<ProcessorType> getInterceptedNodes();
+    List<ProcessorDefinition> getInterceptedNodes();
 
 }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/util/MainSupport.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/util/MainSupport.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/util/MainSupport.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/util/MainSupport.java Fri Mar  6 08:20:00 2009
@@ -34,7 +34,7 @@
 import org.apache.camel.builder.RouteBuilder;
 import org.apache.camel.impl.DefaultCamelContext;
 import org.apache.camel.impl.ServiceSupport;
-import org.apache.camel.model.RouteType;
+import org.apache.camel.model.RouteDefinition;
 import org.apache.camel.processor.interceptor.Debugger;
 import org.apache.camel.view.ModelFileGenerator;
 import org.apache.camel.view.RouteDotGenerator;
@@ -319,8 +319,8 @@
         this.routeBuilders = routeBuilders;
     }
 
-    public List<RouteType> getRouteDefinitions() {
-        List<RouteType> answer = new ArrayList<RouteType>();
+    public List<RouteDefinition> getRouteDefinitions() {
+        List<RouteDefinition> answer = new ArrayList<RouteDefinition>();
         for (CamelContext camelContext : camelContexts) {
             answer.addAll(camelContext.getRouteDefinitions());
         }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProcessorTypeHelper.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProcessorTypeHelper.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProcessorTypeHelper.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/util/ProcessorTypeHelper.java Fri Mar  6 08:20:00 2009
@@ -18,9 +18,9 @@
 
 import java.util.List;
 
-import org.apache.camel.model.ChoiceType;
-import org.apache.camel.model.ProcessorType;
-import org.apache.camel.model.WhenType;
+import org.apache.camel.model.ChoiceDefinition;
+import org.apache.camel.model.ProcessorDefinition;
+import org.apache.camel.model.WhenDefinition;
 
 /**
  * Helper class for ProcessorType and the other model classes.
@@ -39,28 +39,28 @@
      * @return         the first found type, or <tt>null</tt> if not found
      */
     @SuppressWarnings("unchecked")
-    public static <T> T findFirstTypeInOutputs(List<ProcessorType> outputs, Class<T> type) {
+    public static <T> T findFirstTypeInOutputs(List<ProcessorDefinition> outputs, Class<T> type) {
         if (outputs == null || outputs.isEmpty()) {
             return null;
         }
 
-        for (ProcessorType out : outputs) {
+        for (ProcessorDefinition out : outputs) {
             if (type.isInstance(out)) {
                 return type.cast(out);
             }
 
             // special for choice
-            if (out instanceof ChoiceType) {
-                ChoiceType choice = (ChoiceType) out;
-                for (WhenType when : choice.getWhenClauses()) {
-                    List<ProcessorType> children = when.getOutputs();
+            if (out instanceof ChoiceDefinition) {
+                ChoiceDefinition choice = (ChoiceDefinition) out;
+                for (WhenDefinition when : choice.getWhenClauses()) {
+                    List<ProcessorDefinition> children = when.getOutputs();
                     T child = findFirstTypeInOutputs(children, type);
                     if (child != null) {
                         return child;
                     }
                 }
 
-                List<ProcessorType> children = choice.getOtherwise().getOutputs();
+                List<ProcessorDefinition> children = choice.getOtherwise().getOutputs();
                 T child = findFirstTypeInOutputs(children, type);
                 if (child != null) {
                     return child;
@@ -68,7 +68,7 @@
             }
 
             // try children as well
-            List<ProcessorType> children = out.getOutputs();
+            List<ProcessorDefinition> children = out.getOutputs();
             T child = findFirstTypeInOutputs(children, type);
             if (child != null) {
                 return child;

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/view/GraphGeneratorSupport.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/view/GraphGeneratorSupport.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/view/GraphGeneratorSupport.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/view/GraphGeneratorSupport.java Fri Mar  6 08:20:00 2009
@@ -28,13 +28,13 @@
 import java.util.Set;
 
 import org.apache.camel.CamelContext;
-import org.apache.camel.model.ChoiceType;
-import org.apache.camel.model.FromType;
-import org.apache.camel.model.MulticastType;
-import org.apache.camel.model.ProcessorType;
-import org.apache.camel.model.RouteType;
-import org.apache.camel.model.ToType;
-import org.apache.camel.model.language.ExpressionType;
+import org.apache.camel.model.ChoiceDefinition;
+import org.apache.camel.model.FromDefinition;
+import org.apache.camel.model.MulticastDefinition;
+import org.apache.camel.model.ProcessorDefinition;
+import org.apache.camel.model.RouteDefinition;
+import org.apache.camel.model.ToDefinition;
+import org.apache.camel.model.language.ExpressionDefinition;
 import org.apache.camel.util.CollectionStringBuffer;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -52,7 +52,7 @@
     private String imagePrefix = "http://camel.apache.org/images/eip/";
     private Map<Object, NodeData> nodeMap = new HashMap<Object, NodeData>();
     private boolean makeParentDirs = true;
-    private Map<String, List<RouteType>> routeGroupMap;
+    private Map<String, List<RouteDefinition>> routeGroupMap;
 
     protected GraphGeneratorSupport(String dir, String extension) {
         this.dir = dir;
@@ -71,12 +71,12 @@
     }
 
     public String getRoutesText(CamelContext context) throws IOException {
-        List<RouteType> routes = context.getRouteDefinitions();
+        List<RouteDefinition> routes = context.getRouteDefinitions();
         routeGroupMap = createRouteGroupMap(routes);
         return createRouteMapText();
     }
 
-    public String getRouteText(RouteType route) throws IOException {
+    public String getRouteText(RouteDefinition route) throws IOException {
         routeGroupMap = createRouteGroupMap(route);
         return createRouteMapText();
     }
@@ -94,17 +94,17 @@
         if (makeParentDirs) {
             parent.mkdirs();
         }
-        List<RouteType> routes = context.getRouteDefinitions();
+        List<RouteDefinition> routes = context.getRouteDefinitions();
         routeGroupMap = createRouteGroupMap(routes);
 
         // generate the global file
         generateFile(parent, "routes" + extension, routeGroupMap);
 
         if (routeGroupMap.size() >= 1) {
-            Set<Map.Entry<String, List<RouteType>>> entries = routeGroupMap.entrySet();
-            for (Map.Entry<String, List<RouteType>> entry : entries) {
+            Set<Map.Entry<String, List<RouteDefinition>>> entries = routeGroupMap.entrySet();
+            for (Map.Entry<String, List<RouteDefinition>> entry : entries) {
 
-                Map<String, List<RouteType>> map = new HashMap<String, List<RouteType>>();
+                Map<String, List<RouteDefinition>> map = new HashMap<String, List<RouteDefinition>>();
                 String group = entry.getKey();
                 map.put(group, entry.getValue());
 
@@ -114,7 +114,7 @@
         }
     }
 
-    private void generateFile(File parent, String fileName, Map<String, List<RouteType>> map) throws IOException {
+    private void generateFile(File parent, String fileName, Map<String, List<RouteDefinition>> map) throws IOException {
         nodeMap.clear();
         clusterCounter = 0;
 
@@ -126,21 +126,21 @@
         }
     }
 
-    protected abstract void generateFile(PrintWriter writer, Map<String, List<RouteType>> map);
+    protected abstract void generateFile(PrintWriter writer, Map<String, List<RouteDefinition>> map);
 
-    protected boolean isMulticastNode(ProcessorType node) {
-        return node instanceof MulticastType || node instanceof ChoiceType;
+    protected boolean isMulticastNode(ProcessorDefinition node) {
+        return node instanceof MulticastDefinition || node instanceof ChoiceDefinition;
     }
 
-    protected String getLabel(List<ExpressionType> expressions) {
+    protected String getLabel(List<ExpressionDefinition> expressions) {
         CollectionStringBuffer buffer = new CollectionStringBuffer();
-        for (ExpressionType expression : expressions) {
+        for (ExpressionDefinition expression : expressions) {
             buffer.append(getLabel(expression));
         }
         return buffer.toString();
     }
 
-    protected String getLabel(ExpressionType expression) {
+    protected String getLabel(ExpressionDefinition expression) {
         if (expression != null) {
             return expression.getLabel();
         }
@@ -149,11 +149,11 @@
 
     protected NodeData getNodeData(Object node) {
         Object key = node;
-        if (node instanceof FromType) {
-            FromType fromType = (FromType) node;
+        if (node instanceof FromDefinition) {
+            FromDefinition fromType = (FromDefinition) node;
             key = fromType.getUriOrRef();
-        } else if (node instanceof ToType) {
-            ToType toType = (ToType) node;
+        } else if (node instanceof ToDefinition) {
+            ToDefinition toType = (ToDefinition) node;
             key = toType.getUriOrRef();
         }
         NodeData answer = nodeMap.get(key);
@@ -165,28 +165,28 @@
         return answer;
     }
 
-    protected Map<String, List<RouteType>> createRouteGroupMap(List<RouteType> routes) {
-        Map<String, List<RouteType>> map = new HashMap<String, List<RouteType>>();
-        for (RouteType route : routes) {
+    protected Map<String, List<RouteDefinition>> createRouteGroupMap(List<RouteDefinition> routes) {
+        Map<String, List<RouteDefinition>> map = new HashMap<String, List<RouteDefinition>>();
+        for (RouteDefinition route : routes) {
             addRouteToMap(map, route);
         }
         return map;
     }
 
-    protected Map<String, List<RouteType>> createRouteGroupMap(RouteType route) {
-        Map<String, List<RouteType>> map = new HashMap<String, List<RouteType>>();
+    protected Map<String, List<RouteDefinition>> createRouteGroupMap(RouteDefinition route) {
+        Map<String, List<RouteDefinition>> map = new HashMap<String, List<RouteDefinition>>();
         addRouteToMap(map, route);
         return map;
     }
 
-    protected void addRouteToMap(Map<String, List<RouteType>> map, RouteType route) {
+    protected void addRouteToMap(Map<String, List<RouteDefinition>> map, RouteDefinition route) {
         String group = route.getGroup();
         if (group == null) {
             group = "Camel Routes";
         }
-        List<RouteType> list = map.get(group);
+        List<RouteDefinition> list = map.get(group);
         if (list == null) {
-            list = new ArrayList<RouteType>();
+            list = new ArrayList<RouteDefinition>();
             map.put(group, list);
         }
         list.add(route);

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/view/ModelFileGenerator.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/view/ModelFileGenerator.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/view/ModelFileGenerator.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/view/ModelFileGenerator.java Fri Mar  6 08:20:00 2009
@@ -44,8 +44,8 @@
 import org.apache.camel.RuntimeTransformException;
 import org.apache.camel.builder.xml.Namespaces;
 import org.apache.camel.converter.jaxp.XmlConverter;
-import org.apache.camel.model.RouteType;
-import org.apache.camel.model.RoutesType;
+import org.apache.camel.model.RouteDefinition;
+import org.apache.camel.model.RoutesDefinition;
 import org.apache.camel.util.ObjectHelper;
 
 public class ModelFileGenerator {
@@ -61,7 +61,7 @@
     /**
      * Write the specified 'routeTypes' to 'fileName' as XML using JAXB.
      */
-    public void marshalRoutesUsingJaxb(String fileName, List<RouteType> routeTypes) throws IOException {
+    public void marshalRoutesUsingJaxb(String fileName, List<RouteDefinition> routeTypes) throws IOException {
         OutputStream outputStream = outputStream(fileName);
 
         try {
@@ -72,7 +72,7 @@
             root.setAttribute("xmlns", Namespaces.DEFAULT_NAMESPACE);
             doc.appendChild(root);
 
-            for (RouteType routeType : routeTypes) {
+            for (RouteDefinition routeType : routeTypes) {
                 addJaxbElementToNode(root, routeType);
             }
 
@@ -127,7 +127,7 @@
      * Return the root element name for the list of routes.
      */
     private String rootElementName() {
-        XmlRootElement annotation = (RoutesType.class).getAnnotation(XmlRootElement.class);
+        XmlRootElement annotation = (RoutesDefinition.class).getAnnotation(XmlRootElement.class);
         if (annotation != null) {
             String elementName = annotation.name();
             if (ObjectHelper.isNotEmpty(elementName)) {

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/view/NodeData.java Fri Mar  6 08:20:00 2009
@@ -19,19 +19,19 @@
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.camel.model.AggregatorType;
+import org.apache.camel.model.AggregatorDefinition;
 import org.apache.camel.model.BeanRef;
-import org.apache.camel.model.ChoiceType;
-import org.apache.camel.model.FilterType;
-import org.apache.camel.model.FromType;
-import org.apache.camel.model.OtherwiseType;
-import org.apache.camel.model.ProcessorType;
-import org.apache.camel.model.RecipientListType;
-import org.apache.camel.model.ResequencerType;
-import org.apache.camel.model.RoutingSlipType;
-import org.apache.camel.model.SplitterType;
-import org.apache.camel.model.ToType;
-import org.apache.camel.model.WhenType;
+import org.apache.camel.model.ChoiceDefinition;
+import org.apache.camel.model.FilterDefinition;
+import org.apache.camel.model.FromDefinition;
+import org.apache.camel.model.OtherwiseDefinition;
+import org.apache.camel.model.ProcessorDefinition;
+import org.apache.camel.model.RecipientListDefinition;
+import org.apache.camel.model.ResequencerDefinition;
+import org.apache.camel.model.RoutingSlipDefinition;
+import org.apache.camel.model.SplitterDefinition;
+import org.apache.camel.model.ToDefinition;
+import org.apache.camel.model.WhenDefinition;
 
 import static org.apache.camel.util.ObjectHelper.isEmpty;
 import static org.apache.camel.util.ObjectHelper.isNotEmpty;
@@ -51,7 +51,7 @@
     public String nodeType;
     public boolean nodeWritten;
     public String url;
-    public List<ProcessorType> outputs;
+    public List<ProcessorDefinition> outputs;
     public String association = "property";
     private final String imagePrefix;
 
@@ -60,62 +60,62 @@
         this.id = id;
         this.imagePrefix = imagePrefix;
 
-        if (node instanceof ProcessorType) {
-            ProcessorType processorType = (ProcessorType)node;
+        if (node instanceof ProcessorDefinition) {
+            ProcessorDefinition processorType = (ProcessorDefinition)node;
             this.edgeLabel = processorType.getLabel();
         }
-        if (node instanceof FromType) {
-            FromType fromType = (FromType)node;
+        if (node instanceof FromDefinition) {
+            FromDefinition fromType = (FromDefinition)node;
             this.tooltop = fromType.getLabel();
             this.label = removeQueryString(this.tooltop);
             this.url = "http://camel.apache.org/message-endpoint.html";
-        } else if (node instanceof ToType) {
-            ToType toType = (ToType)node;
+        } else if (node instanceof ToDefinition) {
+            ToDefinition toType = (ToDefinition)node;
             this.tooltop = toType.getLabel();
             this.label = removeQueryString(this.tooltop);
             this.edgeLabel = "";
             this.url = "http://camel.apache.org/message-endpoint.html";
-        } else if (node instanceof FilterType) {
+        } else if (node instanceof FilterDefinition) {
             this.image = imagePrefix + "MessageFilterIcon.png";
             this.label = "Filter";
             this.nodeType = "Message Filter";
-        } else if (node instanceof WhenType) {
+        } else if (node instanceof WhenDefinition) {
             this.image = imagePrefix + "MessageFilterIcon.png";
             this.nodeType = "When Filter";
             this.label = "When";
             this.url = "http://camel.apache.org/content-based-router.html";
-        } else if (node instanceof OtherwiseType) {
+        } else if (node instanceof OtherwiseDefinition) {
             this.nodeType = "Otherwise";
             this.edgeLabel = "";
             this.url = "http://camel.apache.org/content-based-router.html";
             this.tooltop = "Otherwise";
-        } else if (node instanceof ChoiceType) {
+        } else if (node instanceof ChoiceDefinition) {
             this.image = imagePrefix + "ContentBasedRouterIcon.png";
             this.nodeType = "Content Based Router";
             this.label = "Choice";
             this.edgeLabel = "";
 
-            ChoiceType choice = (ChoiceType)node;
-            List<ProcessorType> outputs = new ArrayList<ProcessorType>(choice.getWhenClauses());
+            ChoiceDefinition choice = (ChoiceDefinition)node;
+            List<ProcessorDefinition> outputs = new ArrayList<ProcessorDefinition>(choice.getWhenClauses());
             if (choice.getOtherwise() != null) {
                 outputs.add(choice.getOtherwise());
             }
             this.outputs = outputs;
-        } else if (node instanceof RecipientListType) {
+        } else if (node instanceof RecipientListDefinition) {
             this.image = imagePrefix + "RecipientListIcon.png";
             this.nodeType = "Recipient List";
-        } else if (node instanceof RoutingSlipType) {
+        } else if (node instanceof RoutingSlipDefinition) {
             this.image = imagePrefix + "RoutingTableIcon.png";
             this.nodeType = "Routing Slip";
             this.url = "http://camel.apache.org/routing-slip.html";
-            this.tooltop = ((RoutingSlipType) node).getHeaderName();
-        } else if (node instanceof SplitterType) {
+            this.tooltop = ((RoutingSlipDefinition) node).getHeaderName();
+        } else if (node instanceof SplitterDefinition) {
             this.image = imagePrefix + "SplitterIcon.png";
             this.nodeType = "Splitter";
-        } else if (node instanceof AggregatorType) {
+        } else if (node instanceof AggregatorDefinition) {
             this.image = imagePrefix + "AggregatorIcon.png";
             this.nodeType = "Aggregator";
-        } else if (node instanceof ResequencerType) {
+        } else if (node instanceof ResequencerDefinition) {
             this.image = imagePrefix + "ResequencerIcon.png";
             this.nodeType = "Resequencer";
         } else if (node instanceof BeanRef) {
@@ -162,8 +162,8 @@
         if (isEmpty(this.url) && isNotEmpty(this.nodeType)) {
             this.url = "http://camel.apache.org/" + this.nodeType.toLowerCase().replace(' ', '-') + ".html";
         }
-        if (node instanceof ProcessorType && this.outputs == null) {
-            ProcessorType processorType = (ProcessorType)node;
+        if (node instanceof ProcessorDefinition && this.outputs == null) {
+            ProcessorDefinition processorType = (ProcessorDefinition)node;
             this.outputs = processorType.getOutputs();
         }
     }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/view/RouteDotGenerator.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/view/RouteDotGenerator.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/view/RouteDotGenerator.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/view/RouteDotGenerator.java Fri Mar  6 08:20:00 2009
@@ -21,13 +21,13 @@
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.camel.model.FromType;
+import org.apache.camel.model.FromDefinition;
 import org.apache.camel.model.InterceptorRef;
-import org.apache.camel.model.MulticastType;
-import org.apache.camel.model.PipelineType;
-import org.apache.camel.model.ProcessorType;
-import org.apache.camel.model.RouteType;
-import org.apache.camel.model.ToType;
+import org.apache.camel.model.MulticastDefinition;
+import org.apache.camel.model.PipelineDefinition;
+import org.apache.camel.model.ProcessorDefinition;
+import org.apache.camel.model.RouteDefinition;
+import org.apache.camel.model.ToDefinition;
 
 import static org.apache.camel.util.ObjectHelper.isNotEmpty;
 /**
@@ -45,15 +45,15 @@
     // Implementation methods
     //-------------------------------------------------------------------------
 
-    protected void printRoutes(PrintWriter writer, Map<String, List<RouteType>> map) {
-        Set<Map.Entry<String, List<RouteType>>> entries = map.entrySet();
-        for (Map.Entry<String, List<RouteType>> entry : entries) {
+    protected void printRoutes(PrintWriter writer, Map<String, List<RouteDefinition>> map) {
+        Set<Map.Entry<String, List<RouteDefinition>>> entries = map.entrySet();
+        for (Map.Entry<String, List<RouteDefinition>> entry : entries) {
             String group = entry.getKey();
             printRoutes(writer, group, entry.getValue());
         }
     }
 
-    protected void printRoutes(PrintWriter writer, String group, List<RouteType> routes) {
+    protected void printRoutes(PrintWriter writer, String group, List<RouteDefinition> routes) {
         if (group != null) {
             writer.println("subgraph cluster_" + (clusterCounter++) + " {");
             writer.println("label = \"" + group + "\";");
@@ -62,9 +62,9 @@
             writer.println("URL = \"" + group + ".html\";");
             writer.println();
         }
-        for (RouteType route : routes) {
-            List<FromType> inputs = route.getInputs();
-            for (FromType input : inputs) {
+        for (RouteDefinition route : routes) {
+            List<FromDefinition> inputs = route.getInputs();
+            for (FromDefinition input : inputs) {
                 printRoute(writer, route, input);
             }
             writer.println();
@@ -79,7 +79,7 @@
         return text.replace('.', '_').replace("$", "_");
     }
 
-    protected void printRoute(PrintWriter writer, final RouteType route, FromType input) {
+    protected void printRoute(PrintWriter writer, final RouteDefinition route, FromDefinition input) {
         NodeData nodeData = getNodeData(input);
 
         printNode(writer, nodeData);
@@ -87,19 +87,19 @@
         // TODO we should add a transactional client / event driven consumer / polling client
 
         NodeData from = nodeData;
-        for (ProcessorType output : route.getOutputs()) {
+        for (ProcessorDefinition output : route.getOutputs()) {
             NodeData newData = printNode(writer, from, output);
             from = newData;
         }
     }
 
     @SuppressWarnings("unchecked")
-    protected NodeData printNode(PrintWriter writer, NodeData fromData, ProcessorType node) {
-        if (node instanceof MulticastType || node instanceof InterceptorRef) {
+    protected NodeData printNode(PrintWriter writer, NodeData fromData, ProcessorDefinition node) {
+        if (node instanceof MulticastDefinition || node instanceof InterceptorRef) {
             // no need for a multicast or interceptor node
-            List<ProcessorType> outputs = node.getOutputs();
+            List<ProcessorDefinition> outputs = node.getOutputs();
             boolean isPipeline = isPipeline(node);
-            for (ProcessorType output : outputs) {
+            for (ProcessorDefinition output : outputs) {
                 NodeData out = printNode(writer, fromData, output);
                 // if in pipeline then we should move the from node to the next in the pipeline
                 if (isPipeline) {
@@ -127,9 +127,9 @@
 
         // now lets write any children
         //List<ProcessorType> outputs = node.getOutputs();
-        List<ProcessorType> outputs = toData.outputs;
+        List<ProcessorDefinition> outputs = toData.outputs;
         if (outputs != null) {
-            for (ProcessorType output : outputs) {
+            for (ProcessorDefinition output : outputs) {
                 NodeData newData = printNode(writer, toData, output);
                 if (!isMulticastNode(node)) {
                     toData = newData;
@@ -169,7 +169,7 @@
         }
     }
 
-    protected void generateFile(PrintWriter writer, Map<String, List<RouteType>> map) {
+    protected void generateFile(PrintWriter writer, Map<String, List<RouteDefinition>> map) {
         writer.println("digraph CamelRoutes {");
         writer.println();
 
@@ -184,17 +184,17 @@
     /**
      * Is the given node a pipeline
      */
-    private static boolean isPipeline(ProcessorType node) {
-        if (node instanceof MulticastType) {
+    private static boolean isPipeline(ProcessorDefinition node) {
+        if (node instanceof MulticastDefinition) {
             return false;
         }
-        if (node instanceof PipelineType) {
+        if (node instanceof PipelineDefinition) {
             return true;
         }
         if (node.getOutputs().size() > 1) {
             // is pipeline if there is more than 1 output and they are all To types
             for (Object type : node.getOutputs()) {
-                if (!(type instanceof ToType)) {
+                if (!(type instanceof ToDefinition)) {
                     return false;
                 }
             }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/view/XmlGraphGenerator.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/view/XmlGraphGenerator.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/view/XmlGraphGenerator.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/view/XmlGraphGenerator.java Fri Mar  6 08:20:00 2009
@@ -21,10 +21,10 @@
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.camel.model.FromType;
-import org.apache.camel.model.MulticastType;
-import org.apache.camel.model.ProcessorType;
-import org.apache.camel.model.RouteType;
+import org.apache.camel.model.FromDefinition;
+import org.apache.camel.model.MulticastDefinition;
+import org.apache.camel.model.ProcessorDefinition;
+import org.apache.camel.model.RouteDefinition;
 import static org.apache.camel.util.ObjectHelper.isEmpty;
 
 /**
@@ -37,7 +37,7 @@
         super(dir, ".xml");
     }
 
-    protected void generateFile(PrintWriter writer, Map<String, List<RouteType>> map) {
+    protected void generateFile(PrintWriter writer, Map<String, List<RouteDefinition>> map) {
         writer.println("<?xml version='1.0' encoding='UTF-8'?>");
         writer.println("<Graph>");
         writer.println();
@@ -51,15 +51,15 @@
         writer.println("</Graph>");
     }
 
-    protected void printRoutes(PrintWriter writer, Map<String, List<RouteType>> map) {
-        Set<Map.Entry<String, List<RouteType>>> entries = map.entrySet();
-        for (Map.Entry<String, List<RouteType>> entry : entries) {
+    protected void printRoutes(PrintWriter writer, Map<String, List<RouteDefinition>> map) {
+        Set<Map.Entry<String, List<RouteDefinition>>> entries = map.entrySet();
+        for (Map.Entry<String, List<RouteDefinition>> entry : entries) {
             String group = entry.getKey();
             printRoutes(writer, group, entry.getValue());
         }
     }
 
-    protected void printRoutes(PrintWriter writer, String group, List<RouteType> routes) {
+    protected void printRoutes(PrintWriter writer, String group, List<RouteDefinition> routes) {
         group = encode(group);
         if (group != null) {
             int idx = group.lastIndexOf('.');
@@ -70,10 +70,10 @@
             writer.println("<Node id='" + group + "' name='" + name + "' description='" + group + "' nodeType='group'/>");
             writer.println("<Edge fromID='root' toID='" + group + "'/>");
         }
-        for (RouteType route : routes) {
-            List<FromType> inputs = route.getInputs();
+        for (RouteDefinition route : routes) {
+            List<FromDefinition> inputs = route.getInputs();
             boolean first = true;
-            for (FromType input : inputs) {
+            for (FromDefinition input : inputs) {
                 NodeData nodeData = getNodeData(input);
                 if (first) {
                     first = false;
@@ -87,24 +87,24 @@
         }
     }
 
-    protected void printRoute(PrintWriter writer, final RouteType route, NodeData nodeData) {
+    protected void printRoute(PrintWriter writer, final RouteDefinition route, NodeData nodeData) {
         printNode(writer, nodeData);
 
         // TODO we should add a transactional client / event driven consumer / polling client
 
         NodeData from = nodeData;
-        for (ProcessorType output : route.getOutputs()) {
+        for (ProcessorDefinition output : route.getOutputs()) {
             NodeData newData = printNode(writer, from, output);
             from = newData;
         }
     }
 
     @SuppressWarnings("unchecked")
-    protected NodeData printNode(PrintWriter writer, NodeData fromData, ProcessorType node) {
-        if (node instanceof MulticastType) {
+    protected NodeData printNode(PrintWriter writer, NodeData fromData, ProcessorDefinition node) {
+        if (node instanceof MulticastDefinition) {
             // no need for a multicast node
-            List<ProcessorType> outputs = node.getOutputs();
-            for (ProcessorType output : outputs) {
+            List<ProcessorDefinition> outputs = node.getOutputs();
+            for (ProcessorDefinition output : outputs) {
                 printNode(writer, fromData, output);
             }
             return fromData;
@@ -127,9 +127,9 @@
         }
 
         // now lets write any children
-        List<ProcessorType> outputs = toData.outputs;
+        List<ProcessorDefinition> outputs = toData.outputs;
         if (outputs != null) {
-            for (ProcessorType output : outputs) {
+            for (ProcessorDefinition output : outputs) {
                 NodeData newData = printNode(writer, toData, output);
                 if (!isMulticastNode(node)) {
                     toData = newData;

Modified: camel/trunk/camel-core/src/main/resources/org/apache/camel/model/config/jaxb.index
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/resources/org/apache/camel/model/config/jaxb.index?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/resources/org/apache/camel/model/config/jaxb.index (original)
+++ camel/trunk/camel-core/src/main/resources/org/apache/camel/model/config/jaxb.index Fri Mar  6 08:20:00 2009
@@ -14,7 +14,7 @@
 ## See the License for the specific language governing permissions and
 ## limitations under the License.
 ## ------------------------------------------------------------------------
-PropertyType
-PropertiesType
-StreamResequencerConfig
 BatchResequencerConfig
+PropertiesDefinition
+PropertyDefinition
+StreamResequencerConfig

Modified: camel/trunk/camel-core/src/main/resources/org/apache/camel/model/dataformat/jaxb.index
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/resources/org/apache/camel/model/dataformat/jaxb.index?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/resources/org/apache/camel/model/dataformat/jaxb.index (original)
+++ camel/trunk/camel-core/src/main/resources/org/apache/camel/model/dataformat/jaxb.index Fri Mar  6 08:20:00 2009
@@ -18,8 +18,8 @@
 ArtixDSDataFormat
 CsvDataFormat
 HL7DataFormat
-DataFormatType
-DataFormatsType
+DataFormatDefinition
+DataFormatsDefinition
 JaxbDataFormat
 JsonDataFormat
 RssDataFormat

Modified: camel/trunk/camel-core/src/main/resources/org/apache/camel/model/jaxb.index
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/resources/org/apache/camel/model/jaxb.index?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/resources/org/apache/camel/model/jaxb.index (original)
+++ camel/trunk/camel-core/src/main/resources/org/apache/camel/model/jaxb.index Fri Mar  6 08:20:00 2009
@@ -14,57 +14,58 @@
 ## See the License for the specific language governing permissions and
 ## limitations under the License.
 ## ------------------------------------------------------------------------
-AggregatorType
+AggregatorDefinition
 BeanRef
-CatchType
-ChoiceType
-ConvertBodyType
-DelayerType
-Description
-EnricherType
-ExceptionType
-ExpressionSubElementType
-FilterType
-FinallyType
-FromType
-IdempotentConsumerType
-InOnlyType
-InOutType
-InterceptType
+CatchDefinition
+ChoiceDefinition
+ConvertBodyDefinition
+DelayerDefinition
+DescriptionDefinition
+EnricherDefinition
+ExceptionDefinition
+ExpressionSubElementDefinition
+FilterDefinition
+FinallyDefinition
+FromDefinition
+HandleFaultDefinition
+IdempotentConsumerDefinition
+InOnlyDefinition
+InOutDefinition
+InterceptorDefinition
 InterceptorRef
-InterceptorType
-LoadBalanceType
-LoopType
-MarshalType
-MulticastType
+InterceptDefinition
+LoadBalanceDefinition
+LoopDefinition
+MarshalDefinition
+MulticastDefinition
 OptionalIdentifiedType
-OtherwiseType
-PipelineType
+OtherwiseDefinition
+PipelineDefinition
 PolicyRef
-ProceedType
+ProceedDefinition
 ProcessorRef
-RecipientListType
-RedeliveryPolicyType
-RemoveHeaderType
-RemovePropertyType
-ResequencerType
-RouteType
+RecipientListDefinition
+RedeliveryPolicyDefinition
+RemoveHeaderDefinition
+RemovePropertyDefinition
+ResequencerDefinition
 RouteBuilderRef
-RoutesType
-RoutingSlipType
-SetBodyType
-SetExchangePatternType
-SetHeaderType
-SetOutHeaderType
-SetPropertyType
-SplitterType
-SortType
-StopType
-ThrottlerType
-ThreadType
-ThrowFaultType
-ToType
-TransformType
-TryType
-UnmarshalType
-WhenType
+RouteDefinition
+RoutesDefinition
+RoutingSlipDefinition
+SetBodyDefinition
+SetExchangePatternDefinition
+SetHeaderDefinition
+SetOutHeaderDefinition
+SetPropertyDefinition
+SortDefinition
+SplitterDefinition
+StopDefinition
+ThreadDefinition
+ThrottlerDefinition
+ThrowFaultDefinition
+ToDefinition
+TransformDefinition
+TryDefinition
+UnmarshalDefinition
+WhenDefinition

Modified: camel/trunk/camel-core/src/main/resources/org/apache/camel/model/language/jaxb.index
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/resources/org/apache/camel/model/language/jaxb.index?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/resources/org/apache/camel/model/language/jaxb.index (original)
+++ camel/trunk/camel-core/src/main/resources/org/apache/camel/model/language/jaxb.index Fri Mar  6 08:20:00 2009
@@ -16,7 +16,7 @@
 ## ------------------------------------------------------------------------
 ConstantExpression
 ELExpression
-ExpressionType
+ExpressionDefinition
 GroovyExpression
 HeaderExpression
 JavaScriptExpression

Modified: camel/trunk/camel-core/src/main/resources/org/apache/camel/model/loadbalancer/jaxb.index
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/resources/org/apache/camel/model/loadbalancer/jaxb.index?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/resources/org/apache/camel/model/loadbalancer/jaxb.index (original)
+++ camel/trunk/camel-core/src/main/resources/org/apache/camel/model/loadbalancer/jaxb.index Fri Mar  6 08:20:00 2009
@@ -14,8 +14,8 @@
 ## See the License for the specific language governing permissions and
 ## limitations under the License.
 ## ------------------------------------------------------------------------
-LoadBalancerType
 FailOverLoadBalanceStrategy
+LoadBalancerDefinition
 RandomLoadBalanceStrategy
 RoundRobinLoadBalanceStrategy
 StickyLoadBalanceStrategy

Modified: camel/trunk/camel-core/src/test/java/org/apache/camel/impl/StartAndStopRoutesTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/test/java/org/apache/camel/impl/StartAndStopRoutesTest.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/test/java/org/apache/camel/impl/StartAndStopRoutesTest.java (original)
+++ camel/trunk/camel-core/src/test/java/org/apache/camel/impl/StartAndStopRoutesTest.java Fri Mar  6 08:20:00 2009
@@ -22,8 +22,8 @@
 import org.apache.camel.builder.RouteBuilder;
 import org.apache.camel.component.mock.MockEndpoint;
 import org.apache.camel.component.seda.SedaEndpoint;
-import org.apache.camel.model.FromType;
-import org.apache.camel.model.RouteType;
+import org.apache.camel.model.FromDefinition;
+import org.apache.camel.model.RouteDefinition;
 
 /**
  * This test stops a route, mutates it then restarts it
@@ -37,9 +37,9 @@
     protected Object expectedBody = "<hello>world!</hello>";
 
     public void testStartRouteThenStopMutateAndStartRouteAgain() throws Exception {
-        List<RouteType> routes = context.getRouteDefinitions();
+        List<RouteDefinition> routes = context.getRouteDefinitions();
         assertCollectionSize("Route", routes, 1);
-        RouteType route = routes.get(0);
+        RouteDefinition route = routes.get(0);
 
         endpointA = getMandatoryEndpoint("seda:test.a", SedaEndpoint.class);
         endpointB = getMandatoryEndpoint("seda:test.b", SedaEndpoint.class);
@@ -57,7 +57,7 @@
 
 
         // lets mutate the route...
-        FromType fromType = assertOneElement(route.getInputs());
+        FromDefinition fromType = assertOneElement(route.getInputs());
         fromType.setUri("seda:test.C");
         context.startRoute(route);
 

Modified: camel/trunk/camel-core/src/test/java/org/apache/camel/issues/TwoTimerWithJMXIssue.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/test/java/org/apache/camel/issues/TwoTimerWithJMXIssue.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/test/java/org/apache/camel/issues/TwoTimerWithJMXIssue.java (original)
+++ camel/trunk/camel-core/src/test/java/org/apache/camel/issues/TwoTimerWithJMXIssue.java Fri Mar  6 08:20:00 2009
@@ -19,7 +19,7 @@
 import org.apache.camel.ContextTestSupport;
 import org.apache.camel.Processor;
 import org.apache.camel.builder.RouteBuilder;
-import org.apache.camel.model.ProcessorType;
+import org.apache.camel.model.ProcessorDefinition;
 import org.apache.camel.spi.InterceptStrategy;
 
 /**
@@ -53,7 +53,7 @@
     }
 
     private class MyTracer implements InterceptStrategy {
-        public Processor wrapProcessorInInterceptors(ProcessorType processorType, Processor target)
+        public Processor wrapProcessorInInterceptors(ProcessorDefinition processorType, Processor target)
             throws Exception {
             assertNotNull(target);
             counter++;

Modified: camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmFromCamelContextlTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmFromCamelContextlTest.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmFromCamelContextlTest.java (original)
+++ camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmFromCamelContextlTest.java Fri Mar  6 08:20:00 2009
@@ -30,9 +30,9 @@
 public class GenerateXmFromCamelContextlTest extends ContextTestSupport {
 
     public void testCreateRouteFromCamelCOntext() throws Exception {
-        List<RouteType> list = context.getRouteDefinitions();
+        List<RouteDefinition> list = context.getRouteDefinitions();
         assertEquals("Size of list " + list, 1, list.size());
-        RouteType routeType = list.get(0);
+        RouteDefinition routeType = list.get(0);
 
         log.info("Found route: " + routeType);
 

Modified: camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmlTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmlTest.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmlTest.java (original)
+++ camel/trunk/camel-core/src/test/java/org/apache/camel/model/GenerateXmlTest.java Fri Mar  6 08:20:00 2009
@@ -30,8 +30,8 @@
 public class GenerateXmlTest extends XmlTestSupport {
 
     public void testCreateSimpleXml() throws Exception {
-        RoutesType context = new RoutesType();
-        RouteType route = context.route();
+        RoutesDefinition context = new RoutesDefinition();
+        RouteDefinition route = context.route();
         route.from("seda:a");
         route.filter(new XQueryExpression("in.header.foo == 'bar'")).
                 to("seda:b");
@@ -40,14 +40,14 @@
     }
 
     public void testGroovyFilterXml() throws Exception {
-        RoutesType context = new RoutesType();
-        RouteType route = context.route();
+        RoutesDefinition context = new RoutesDefinition();
+        RouteDefinition route = context.route();
         route.from("seda:a");
         route.interceptors("interceptor1", "interceptor2");
         route.filter(new GroovyExpression("in.headers.any { h -> h.startsWith('foo') }")).
                 to("seda:b");
         route.description(null, "This is a description of the route", "en");
-        List<ProcessorType> list = route.getOutputs();
+        List<ProcessorDefinition> list = route.getOutputs();
         assertEquals("Size of list: " + list, 1, list.size());
 
         dump(context);
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/DefaultExceptionPolicyStrategy.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/DefaultExceptionPolicyStrategy.java Fri Mar  6 08:20:00 2009
@@ -24,12 +24,12 @@
 import java.util.Set;
 
 import org.apache.camel.Exchange;
-import org.apache.camel.model.ExceptionType;
+import org.apache.camel.model.ExceptionDefinition;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 /**
  * The default strategy used in Camel to resolve the {@link org.apache.camel.model.ExceptionType} that should
  * handle the thrown exception.
  * <p/>
  * <b>Selection strategy:</b>
@@ -39,7 +39,7 @@
  * by is selected first, ending with the thrown exception itself. The method {@link #createExceptionIterator(Throwable)}
  * provides the Iterator used for the walking.</li>
  * <li>The exception type must be configured with an Exception that is an instance of the thrown exception, this
  * is tested using the {@link #filter(org.apache.camel.model.ExceptionType, Class, Throwable)} method.
  * By default the filter uses <tt>instanceof</tt> test.</li>
  * <li>If the exception type has <b>exactly</b> the thrown exception then its selected as its an exact match</li>
  * <li>Otherwise the type that has an exception that is the closets super of the thrown exception is selected
@@ -47,8 +47,8 @@
  * </ul>
  * <p/>
  * <b>Fine grained matching:</b>
  * <br/> If the {@link ExceptionType} has a when defined with an expression the type is also matches against
  * the current exchange using the {@link #matchesWhen(org.apache.camel.model.ExceptionType, org.apache.camel.Exchange)}
  * method. This can be used to for more fine grained matching, so you can e.g. define multiple sets of
  * exception types with the same exception class(es) but have a predicate attached to select which to select at runtime.
  */
@@ -56,13 +56,13 @@
 
     private static final transient Log LOG = LogFactory.getLog(DefaultExceptionPolicyStrategy.class);
 
-    public ExceptionType getExceptionPolicy(Map<ExceptionPolicyKey, ExceptionType> exceptionPolicices, Exchange exchange,
+    public ExceptionDefinition getExceptionPolicy(Map<ExceptionPolicyKey, ExceptionDefinition> exceptionPolicices, Exchange exchange,
                                             Throwable exception) {
 
         // recursive up the tree using the iterator
         Iterator<Throwable> it = createExceptionIterator(exception); 
         while (it.hasNext()) {
-            ExceptionType type = findMatchedExceptionPolicy(exceptionPolicices, exchange, it.next());
+            ExceptionDefinition type = findMatchedExceptionPolicy(exceptionPolicices, exchange, it.next());
             if (type != null) {
                 return type;
             }
@@ -73,7 +73,7 @@
     }
 
 
-    private ExceptionType findMatchedExceptionPolicy(Map<ExceptionPolicyKey, ExceptionType> exceptionPolicices, Exchange exchange,
+    private ExceptionDefinition findMatchedExceptionPolicy(Map<ExceptionPolicyKey, ExceptionDefinition> exceptionPolicices, Exchange exchange,
                                                Throwable exception) {
         if (LOG.isDebugEnabled()) {
             LOG.debug("Finding best suited exception policy for thrown exception " + exception.getClass().getName());
@@ -82,15 +82,15 @@
         // the goal is to find the exception with the same/closet inheritance level as the target exception being thrown
         int targetLevel = getInheritanceLevel(exception.getClass());
         // candidate is the best candidate found so far to return
-        ExceptionType candidate = null;
+        ExceptionDefinition candidate = null;
         // difference in inheritance level between the current candidate and the thrown exception (target level)
         int candidateDiff = Integer.MAX_VALUE;
 
         // loop through all the entries and find the best candidates to use
-        Set<Map.Entry<ExceptionPolicyKey, ExceptionType>> entries = exceptionPolicices.entrySet();
-        for (Map.Entry<ExceptionPolicyKey, ExceptionType> entry : entries) {
+        Set<Map.Entry<ExceptionPolicyKey, ExceptionDefinition>> entries = exceptionPolicices.entrySet();
+        for (Map.Entry<ExceptionPolicyKey, ExceptionDefinition> entry : entries) {
             Class clazz = entry.getKey().getExceptionClass();
-            ExceptionType type = entry.getValue();
+            ExceptionDefinition type = entry.getValue();
 
             if (filter(type, clazz, exception)) {
 
@@ -139,7 +139,7 @@
      * @param exception      the thrown exception
      * @return <tt>true</tt> if the to current exception class is a candidate, <tt>false</tt> to skip it.
      */
-    protected boolean filter(ExceptionType type, Class exceptionClass, Throwable exception) {
+    protected boolean filter(ExceptionDefinition type, Class exceptionClass, Throwable exception) {
         // must be instance of check to ensure that the exceptionClass is one type of the thrown exception
         return exceptionClass.isInstance(exception);
     }
@@ -157,7 +157,7 @@
      * @param exchange the current {@link Exchange}
      * @return <tt>true</tt> if matched, <tt>false</tt> otherwise.
      */
-    protected boolean matchesWhen(ExceptionType type, Exchange exchange) {
+    protected boolean matchesWhen(ExceptionDefinition type, Exchange exchange) {
         if (type.getOnWhen() == null || type.getOnWhen().getExpression() == null) {
             // if no predicate then it's always a match
             return true;
@@ -167,7 +167,7 @@
 
     /**
      * Strategy method creating the iterator to walk the exception in the order Camel should use
      * for find the {@link ExceptionType} should be used.
      * <p/>
      * The default iterator will walk from the bottom upwards
      * (the last caused by going upwards to the exception)
@@ -24,12 +24,12 @@
 
 /**
- * The default strategy used in Camel to resolve the {@link org.apache.camel.model.ExceptionType} that should
+ * The default strategy used in Camel to resolve the {@link org.apache.camel.model.ExceptionDefinition} that should
  * handle the thrown exception.
  * <p/>
@@ -39,7 +39,7 @@
  * provides the Iterator used for the walking.</li>
  * <li>The exception type must be configured with an Exception that is an instance of the thrown exception, this
- * is tested using the {@link #filter(org.apache.camel.model.ExceptionType, Class, Throwable)} method.
+ * is tested using the {@link #filter(org.apache.camel.model.ExceptionDefinition, Class, Throwable)} method.
  * By default the filter uses <tt>instanceof</tt> test.</li>
  * <li>If the exception type has <b>exactly</b> the thrown exception then its selected as its an exact match</li>
@@ -47,8 +47,8 @@
  * <p/>
  * <b>Fine grained matching:</b>
- * <br/> If the {@link ExceptionType} has a when defined with an expression the type is also matches against
- * the current exchange using the {@link #matchesWhen(org.apache.camel.model.ExceptionType, org.apache.camel.Exchange)}
+ * <br/> If the {@link ExceptionDefinition} has a when defined with an expression the type is also matches against
+ * the current exchange using the {@link #matchesWhen(org.apache.camel.model.ExceptionDefinition, org.apache.camel.Exchange)}
  * method. This can be used to for more fine grained matching, so you can e.g. define multiple sets of
  * exception types with the same exception class(es) but have a predicate attached to select which to select at runtime.
@@ -167,7 +167,7 @@
     /**
      * Strategy method creating the iterator to walk the exception in the order Camel should use
-     * for find the {@link ExceptionType} should be used.
+     * for find the {@link ExceptionDefinition} should be used.
      * <p/>
      * The default iterator will walk from the bottom upwards

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyKey.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyKey.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyStrategy.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/processor/exceptionpolicy/ExceptionPolicyStrategy.java Fri Mar  6 08:20:00 2009
@@ -19,10 +19,10 @@
 import java.util.Map;
 
 import org.apache.camel.Exchange;
-import org.apache.camel.model.ExceptionType;
+import org.apache.camel.model.ExceptionDefinition;
 
 /**
  * A strategy to determine which {@link org.apache.camel.model.ExceptionType} should handle the thrown
  * exception.
  *
  * @see org.apache.camel.processor.exceptionpolicy.DefaultExceptionPolicyStrategy DefaultExceptionPolicy
@@ -30,14 +30,14 @@
 public interface ExceptionPolicyStrategy {
 
     /**
      * Resolves the {@link org.apache.camel.model.ExceptionType} that should handle the thrown exception.
      *
      * @param exceptionPolicices the configured exception policies to resolve from
      * @param exchange           the exchange
      * @param exception          the exception that was thrown
      * @return the resolved exception type to handle this exception, <tt>null</tt> if none found.
      */
-    ExceptionType getExceptionPolicy(Map<ExceptionPolicyKey, ExceptionType> exceptionPolicices, Exchange exchange,
+    ExceptionDefinition getExceptionPolicy(Map<ExceptionPolicyKey, ExceptionDefinition> exceptionPolicices, Exchange exchange,
                                             Throwable exception);
 
 }
@@ -19,10 +19,10 @@
 
 /**
- * A strategy to determine which {@link org.apache.camel.model.ExceptionType} should handle the thrown
+ * A strategy to determine which {@link org.apache.camel.model.ExceptionDefinition} should handle the thrown
  * exception.
  *
@@ -30,14 +30,14 @@
 
     /**
-     * Resolves the {@link org.apache.camel.model.ExceptionType} that should handle the thrown exception.
+     * Resolves the {@link org.apache.camel.model.ExceptionDefinition} that should handle the thrown exception.
      *
      * @param exceptionPolicices the configured exception policies to resolve from

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DebugInterceptor.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/interceptor/DebugInterceptor.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================